Download ROADMAP chromHMM BED files from the WashU Epigenome Browser, optionally subset to a specific chromatin state, and return paths to the processed files.

GOSHIFTER_get_roadmap_annotations(
  annotations_path = "./annotations",
  bed_list,
  chromatin_state = "TssA",
  verbose = TRUE
)

Arguments

annotations_path

Directory where annotation files are stored/cached.

bed_list

Character vector of BED file names (as produced by GOSHIFTER_bed_names).

chromatin_state

Chromatin state to subset by (e.g. "TssA"). Set to NA to keep all states.

verbose

Print messages (default TRUE).

Value

A character vector of paths to processed BED files (gzipped).