Parses the metadata and adds it as columns, and then merges the results into a single GRangesList

XGR_merge_and_process(grl.xgr, lib, n_top_sources = 10)

Arguments

grl.xgr

GRangesList of XGR queries.