Plot any missense variants in fine-mapped data.
Usage
plot_missense(
merged_DT,
snp_filter = "Support>0",
label_yaxis = FALSE,
x_label = "UCS missense\nmutations",
show.legend = TRUE,
show_numbers = FALSE,
show_plot = TRUE
)Arguments
- merged_DT
Merged fine-mapping results data from
echolocatoR::finemap_loci.- snp_filter
Filter to use apply to SNPs before plotting.
- label_yaxis
Whether to label the y-axis.
- x_label
x-axis title.
- show.legend
logical. Should this layer be included in the legends?
NA, the default, includes if any aesthetics are mapped.FALSEnever includes, andTRUEalways includes. It can also be a named logical vector to finely select the aesthetics to display. To include legend keys for all levels, even when no data exists, useTRUE. IfNA, all levels are shown in legend, but unobserved levels are omitted.- show_numbers
Whether to plot the numeric values or not.
- show_plot
Show plot.
Examples
if (FALSE) { # \dontrun{
merged_DT <- echodata::get_Nalls2019_merged()
gg_missense <- plot_missense(
merged_DT = merged_DT,
snp_filter = "Support>0"
)
gg_missense <- plot_missense(
merged_DT = merged_DT,
snp_filter = "Consensus_SNP==TRUE"
)
} # }