R/GOSHIFTER_utils.R
GOSHIFTER_get_roadmap_annotations.RdDownload ROADMAP chromHMM BED files from the WashU Epigenome Browser, optionally subset to a specific chromatin state, and return paths to the processed files.
GOSHIFTER_get_roadmap_annotations(
annotations_path = "./annotations",
bed_list,
chromatin_state = "TssA",
verbose = TRUE
)Directory where annotation files are stored/cached.
Character vector of BED file names (as produced by
GOSHIFTER_bed_names).
Chromatin state to subset by
(e.g. "TssA"). Set to NA to keep all states.
Print messages (default TRUE).
A character vector of paths to processed BED files (gzipped).
Other GOSHIFTER:
GOSHIFTER(),
GOSHIFTER_bed_names(),
GOSHIFTER_check_overlap(),
GOSHIFTER_create_LD(),
GOSHIFTER_create_snpmap(),
GOSHIFTER_find_folder(),
GOSHIFTER_heatmap(),
GOSHIFTER_histograms_SNPgroups(),
GOSHIFTER_histograms_pvals(),
GOSHIFTER_list_chromatin_states(),
GOSHIFTER_process_results(),
GOSHIFTER_run(),
GOSHIFTER_search_ROADMAP(),
GOSHIFTER_summarise_results()