Calculate p-values for each motifbreakR motif disruption result.

MOTIFBREAKR_calc_pvals(
  mb_res,
  background = c(A = 0.25, C = 0.25, G = 0.25, T = 0.25),
  granularity = NULL,
  nThread = 1,
  results_dir = file.path(tempdir(), "results"),
  verbose = TRUE
)

Arguments

mb_res

Results generated by MOTIFBREAKR, in GRanges format.

background

A named numeric vector of background nucleotide frequencies (A, C, G, T) summing to 1.

granularity

Granularity for p-value calculation. If NULL, a default is chosen automatically.

nThread

Number of threads to parallelize analyses across.

results_dir

Directory where results should be saved as a file named: <results_dir>/_genome_wide/motifbreakR/motifbreakR_results.rds. If NULL, results will not be saved to disk.

verbose

Print messages.

Value

Motif disruption predictions in GRanges format, with the p-value columns filled out.

Examples

 
if (FALSE) { # \dontrun{
mb_res <- MOTIFBREAKR(rsid_list = c("rs11175620"),
                      # limit the number of datasets tests 
                      # for demonstration purposes only
                      pwmList_max = 5)
mb_res_p <- MOTIFBREAKR_calc_pvals(mb_res = mb_res)                       
} # }