Merges a list of XGR annotations into a single GRangesList (or merged GRanges) object.
Usage
XGR_query(
lib.selections = c("ENCODE_TFBS_ClusteredV3_CellTypes", "TFBS_Conserved",
"Uniform_TFBS"),
as_grangesList = FALSE,
dat = NULL,
n_top = NULL,
nThread = 1
)Arguments
- lib.selections
Which XGR annotations to check overlap with. For full list of libraries see here (XGR on CRAN). Passed to the
RData.customisedargument inXGR::xRDataLoader.- as_grangesList
Return as a GRangesList, instead of a single merged GRanges object.
- dat
data.table of genomic coordinates to query with. Set as
NULLto return genome-wide data.- n_top
Filter to only the top N annotations that have the greatest amount of overlap with the genomic coordinates of
dat.- nThread
Number of cores to parallelise across.
See also
Other XGR:
XGR_enrichment(),
XGR_enrichment_bootstrap(),
XGR_enrichment_plot(),
XGR_filter_assays(),
XGR_filter_sources(),
XGR_import_annotations(),
XGR_iterate_enrichment(),
XGR_iterate_overlap(),
XGR_merge_and_process(),
XGR_parse_metadata(),
XGR_plot_enrichment(),
XGR_prepare_foreground_background(),
XGR_sep_handler(),
xgr_example